﻿Imports MapControlSamples.Common
Imports System
Imports Windows.ApplicationModel.Resources
Imports Windows.Devices.Geolocation
Imports Windows.UI.Xaml.Controls
Imports Windows.UI.Xaml.Navigation
Imports MapControlSamples.Models

Namespace MapControlSamples

	''' <summary>
	''' A page that displays details for a single item within a group.
	''' </summary>
	Public NotInheritable Partial Class ControlsXamlPage
		Inherits Page

		Private ReadOnly navigationHelper_Renamed As NavigationHelper
		Private ReadOnly resourceLoader As ResourceLoader = ResourceLoader.GetForCurrentView("Resources")

		Public Sub New()
			Me.InitializeComponent()

			Me.navigationHelper_Renamed = New NavigationHelper(Me)
			AddHandler Me.navigationHelper_Renamed.LoadState, AddressOf NavigationHelper_LoadState
			AddHandler Me.navigationHelper_Renamed.SaveState, AddressOf NavigationHelper_SaveState

		End Sub

		''' <summary>
		''' Gets the <see cref="NavigationHelper"/> associated with this <see cref="Page"/>.
		''' </summary>
		Public ReadOnly Property NavigationHelper() As NavigationHelper
			Get
				Return Me.navigationHelper_Renamed
			End Get
		End Property

		''' <summary>
		''' Populates the page with content passed during navigation. Any saved state is also
		''' provided when recreating a page from a prior session.
		''' </summary>
		''' <param name="sender">
		''' The source of the event; typically <see cref="NavigationHelper"/>.
		''' </param>
		''' <param name="e">Event data that provides both the navigation parameter passed to
		''' <see cref="Frame.Navigate(Type, Object)"/> when this page was initially requested and
		''' a dictionary of state preserved by this page during an earlier
		''' session.  The state will be null the first time a page is visited.</param>
		Private Sub NavigationHelper_LoadState(ByVal sender As Object, ByVal e As LoadStateEventArgs)
			' TODO: Create an appropriate data model for your problem domain to replace the sample data.
		End Sub

		''' <summary>
		''' Preserves state associated with this page in case the application is suspended or the
		''' page is discarded from the navigation cache.  Values must conform to the serialization
		''' requirements of <see cref="SuspensionManager.SessionState"/>.
		''' </summary>
		''' <param name="sender">The source of the event; typically <see cref="NavigationHelper"/>.</param>
		''' <param name="e">Event data that provides an empty dictionary to be populated with
		''' serializable state.</param>
		Private Sub NavigationHelper_SaveState(ByVal sender As Object, ByVal e As SaveStateEventArgs)
			' TODO: Save the unique state of the page here.
		End Sub

		#Region "NavigationHelper registration"

		''' <summary>
		''' The methods provided in this section are simply used to allow
		''' NavigationHelper to respond to the page's navigation methods.
		''' <para>
		''' Page specific logic should be placed in event handlers for the  
		''' <see cref="NavigationHelper.LoadState"/>
		''' and <see cref="NavigationHelper.SaveState"/>.
		''' The navigation parameter is available in the LoadState method 
		''' in addition to page state preserved during an earlier session.
		''' </para>
		''' </summary>
		''' <param name="e">Provides data for navigation methods and event
		''' handlers that cannot cancel the navigation request.</param>
		Protected async Overrides Sub OnNavigatedTo(ByVal e As NavigationEventArgs)
			' Call the navigation helper base function.
			Me.navigationHelper_Renamed.OnNavigatedTo(e)

			' Size the Map Control
			myMapControl.Width = Windows.UI.Xaml.Window.Current.Bounds.Width
			myMapControl.Height = Windows.UI.Xaml.Window.Current.Bounds.Height - 85

			' Get the user's current location so that it can be used as the center
			' point of the map control.
			Dim geolocator As New Geolocator()

			' Set the desired accuracy.
			geolocator.DesiredAccuracyInMeters = 20

			' The maximum acceptable age of cached location data. 
			Dim maxAge As New TimeSpan(0, 2, 0)

			' Timeout used for the call to GetGeoposition.
			Dim timeout As New TimeSpan(0, 0, 5)

			Dim geoposition As Geoposition = Nothing
			Try
				geoposition = await geolocator.GetGeopositionAsync(maxAge, timeout)
			Catch e1 As Exception
				' Make sure you have defined ID_CAP_LOCATION in the application manifest 
				' and that on your phone, you have turned on location by checking 
				' Settings > Location.

				' Handle errors like unauthorized access to location services
			End Try

			' Set up the LocationEntity object
			Dim locationEntity As New LocationEntity()
			locationEntity.Location = geoposition.Coordinate.Point
			locationEntity.Message = "You are here"

			' Specify the location that will be at the center of the map.
			myMapControl.Center = locationEntity.Location

			' Set the map controls data context so data binding will work.
			myMapControl.DataContext = locationEntity

			' Zoom level.  
			myMapControl.ZoomLevel = 15

			' Location and Anchorpoint for the image control
			'MapControl.SetLocation(imgMyLocation, geoposition.Coordinate.Point);
			'MapControl.SetNormalizedAnchorPoint(imgMyLocation, new Point(0.5, 0.5));

			' Location and Anchorpoint for the text block
			'MapControl.SetLocation(tbMessage, geoposition.Coordinate.Point);
			'MapControl.SetNormalizedAnchorPoint(tbAddress, new Point(1.0, 1.0));
			'tbAddress.Text = "You are here";

			' The map control has done most of its work.  Make the controls visible
			' and collapse the progress bar.
			imgMyLocation.Visibility = Windows.UI.Xaml.Visibility.Visible
			borderMessage.Visibility = Windows.UI.Xaml.Visibility.Visible

			' Collapse the progress bar.
			pbProgressBar.Visibility = Windows.UI.Xaml.Visibility.Collapsed
		End Sub

		Protected Overrides Sub OnNavigatedFrom(ByVal e As NavigationEventArgs)
			Me.navigationHelper_Renamed.OnNavigatedFrom(e)
		End Sub

		#End Region
	End Class
End Namespace