﻿Imports MapControlSamples.Common
Imports System
Imports Windows.ApplicationModel.Resources
Imports Windows.Devices.Geolocation
Imports Windows.Foundation
Imports Windows.UI.Xaml.Controls
Imports Windows.UI.Xaml.Controls.Maps
Imports Windows.UI.Xaml.Navigation

Namespace MapControlSamples
	''' <summary>
	''' A page that displays details for a single item within a group.
	''' </summary>
	Public NotInheritable Partial Class DefaultImagePage
		Inherits Page

		Private ReadOnly navigationHelper_Renamed As NavigationHelper
		Private ReadOnly resourceLoader As ResourceLoader = ResourceLoader.GetForCurrentView("Resources")

		Public Sub New()
			Me.InitializeComponent()

			Me.navigationHelper_Renamed = New NavigationHelper(Me)
			AddHandler Me.navigationHelper_Renamed.LoadState, AddressOf NavigationHelper_LoadState
			AddHandler Me.navigationHelper_Renamed.SaveState, AddressOf NavigationHelper_SaveState
		End Sub

		''' <summary>
		''' Gets the <see cref="NavigationHelper"/> associated with this <see cref="Page"/>.
		''' </summary>
		Public ReadOnly Property NavigationHelper() As NavigationHelper
			Get
				Return Me.navigationHelper_Renamed
			End Get
		End Property

		''' <summary>
		''' Populates the page with content passed during navigation. Any saved state is also
		''' provided when recreating a page from a prior session.
		''' </summary>
		''' <param name="sender">
		''' The source of the event; typically <see cref="NavigationHelper"/>.
		''' </param>
		''' <param name="e">Event data that provides both the navigation parameter passed to
		''' <see cref="Frame.Navigate(Type, Object)"/> when this page was initially requested and
		''' a dictionary of state preserved by this page during an earlier
		''' session.  The state will be null the first time a page is visited.</param>
		Private Sub NavigationHelper_LoadState(ByVal sender As Object, ByVal e As LoadStateEventArgs)
			' TODO: Create an appropriate data model for your problem domain to replace the sample data.
		End Sub

		''' <summary>
		''' Preserves state associated with this page in case the application is suspended or the
		''' page is discarded from the navigation cache.  Values must conform to the serialization
		''' requirements of <see cref="SuspensionManager.SessionState"/>.
		''' </summary>
		''' <param name="sender">The source of the event; typically <see cref="NavigationHelper"/>.</param>
		''' <param name="e">Event data that provides an empty dictionary to be populated with
		''' serializable state.</param>
		Private Sub NavigationHelper_SaveState(ByVal sender As Object, ByVal e As SaveStateEventArgs)
			' TODO: Save the unique state of the page here.
		End Sub

		#Region "NavigationHelper registration"

		''' <summary>
		''' The methods provided in this section are simply used to allow
		''' NavigationHelper to respond to the page's navigation methods.
		''' <para>
		''' Page specific logic should be placed in event handlers for the  
		''' <see cref="NavigationHelper.LoadState"/>
		''' and <see cref="NavigationHelper.SaveState"/>.
		''' The navigation parameter is available in the LoadState method 
		''' in addition to page state preserved during an earlier session.
		''' </para>
		''' </summary>
		''' <param name="e">Provides data for navigation methods and event
		''' handlers that cannot cancel the navigation request.</param>
		Protected async Overrides Sub OnNavigatedTo(ByVal e As NavigationEventArgs)
			' Call the navigation helper base function.
			Me.navigationHelper_Renamed.OnNavigatedTo(e)

			' Size the Map Control
			myMapControl.Width = Windows.UI.Xaml.Window.Current.Bounds.Width
			myMapControl.Height = Windows.UI.Xaml.Window.Current.Bounds.Height - 85

			' Get the user's current location so that it can be used as the center
			' point of the map control.
			Dim geolocator As New Geolocator()
			Dim geoposition As Geoposition = Nothing
			Try
				geoposition = await geolocator.GetGeopositionAsync()
			Catch e1 As Exception
				' Make sure you have defined ID_CAP_LOCATION in the application manifest 
				' and that on your phone, you have turned on location by checking 
				' Settings > Location.

				' Handle errors like unauthorized access to location services
			End Try

			' Set the map center point.
			myMapControl.Center = geoposition.Coordinate.Point

			' Zoom level
			myMapControl.ZoomLevel = 15

			' Various display options
			myMapControl.LandmarksVisible = False
			myMapControl.TrafficFlowVisible = False
			myMapControl.PedestrianFeaturesVisible = False

			' Create the map icon
			Dim mapIcon As New MapIcon()
			mapIcon.NormalizedAnchorPoint = New Point(0.5, 1.0)
			mapIcon.Location = geoposition.Coordinate.Point

			' Get the text to display above the map icon from the resource files.
			Dim title As String = Me.resourceLoader.GetString("YouAreHere")
			mapIcon.Title = title

			' Add the map icon to the map elements collection.
			myMapControl.MapElements.Add(mapIcon)
		End Sub

		Protected Overrides Sub OnNavigatedFrom(ByVal e As NavigationEventArgs)
			Me.navigationHelper_Renamed.OnNavigatedFrom(e)
		End Sub

		#End Region
	End Class
End Namespace