﻿Imports MapControlSamples.Common
Imports System
Imports System.Collections.Generic
Imports System.Threading.Tasks
Imports Windows.ApplicationModel.Resources
Imports Windows.Devices.Geolocation
Imports Windows.Services.Maps
Imports Windows.UI.Popups
Imports Windows.UI.Xaml.Controls
Imports Windows.UI.Xaml.Input
Imports Windows.UI.Xaml.Navigation

Namespace MapControlSamples
	''' <summary>
	''' A page that displays details for a single item within a group.
	''' </summary>
	Public NotInheritable Partial Class GeocodingPage
		Inherits Page

		Private ReadOnly navigationHelper_Renamed As NavigationHelper
		Private ReadOnly resourceLoader As ResourceLoader = ResourceLoader.GetForCurrentView("Resources")

		Public Sub New()
			Me.InitializeComponent()

			Me.navigationHelper_Renamed = New NavigationHelper(Me)
			AddHandler Me.navigationHelper_Renamed.LoadState, AddressOf NavigationHelper_LoadState
			AddHandler Me.navigationHelper_Renamed.SaveState, AddressOf NavigationHelper_SaveState
		End Sub

		''' <summary>
		''' Gets the <see cref="NavigationHelper"/> associated with this <see cref="Page"/>.
		''' </summary>
		Public ReadOnly Property NavigationHelper() As NavigationHelper
			Get
				Return Me.navigationHelper_Renamed
			End Get
		End Property

		Private Sub tbAddress_KeyUp(ByVal sender As Object, ByVal e As KeyRoutedEventArgs)
			If e.Key = Windows.System.VirtualKey.Enter Then
				geocode(tbAddress.Text)
			End If
		End Sub

		Private async Sub geocode(ByVal address As String)
			' Get the user's current location so it can be used as a starting point 
			' for the location search below.
			Dim geolocator As New Geolocator()
			Dim currentPosition As Geoposition = await geolocator.GetGeopositionAsync()

			' Geocodes the specified address, using the current location
			' as a reference point. Returns no more than 5 results.
			Dim result As MapLocationFinderResult = await MapLocationFinder.FindLocationsAsync(address, currentPosition.Coordinate.Point, 5)

			' list to hold search results
			Dim locations As New List(Of String)()

			' If the query returns results then bind it to the list view.
			If result.Status = MapLocationFinderStatus.Success Then
				For Each mapLocation As MapLocation In result.Locations
					' create a display string of the map location
					Dim display As String = mapLocation.Address.StreetNumber & " " & mapLocation.Address.Street & Environment.NewLine & mapLocation.Address.Town & ", " & mapLocation.Address.RegionCode & "  " & mapLocation.Address.PostCode & Environment.NewLine & mapLocation.Address.CountryCode

					' add the display string to the location list
					locations.Add(display)
				Next mapLocation

				' bind the location list to the ListView control
				lvLocations.ItemsSource = locations

			Else
				' Tell the user to try again.
				Dim message As String = Me.resourceLoader.GetString("NoAddress")
				Dim messageDialog As New MessageDialog(message)
				await messageDialog.ShowAsync()
			End If

			If locations.Count = 0 Then
				' Tell the user to try again.
				Dim message As String = Me.resourceLoader.GetString("NoAddress")
				Dim title As String = Me.resourceLoader.GetString("NoAddressTitle")
				Dim messageDialog As New MessageDialog(message,title)
				await messageDialog.ShowAsync()
			End If
		End Sub


		''' <summary>
		''' Populates the page with content passed during navigation. Any saved state is also
		''' provided when recreating a page from a prior session.
		''' </summary>
		''' <param name="sender">
		''' The source of the event; typically <see cref="NavigationHelper"/>.
		''' </param>
		''' <param name="e">Event data that provides both the navigation parameter passed to
		''' <see cref="Frame.Navigate(Type, Object)"/> when this page was initially requested and
		''' a dictionary of state preserved by this page during an earlier
		''' session.  The state will be null the first time a page is visited.</param>
		Private Sub NavigationHelper_LoadState(ByVal sender As Object, ByVal e As LoadStateEventArgs)
		End Sub

		''' <summary>
		''' Preserves state associated with this page in case the application is suspended or the
		''' page is discarded from the navigation cache.  Values must conform to the serialization
		''' requirements of <see cref="SuspensionManager.SessionState"/>.
		''' </summary>
		''' <param name="sender">The source of the event; typically <see cref="NavigationHelper"/>.</param>
		''' <param name="e">Event data that provides an empty dictionary to be populated with
		''' serializable state.</param>
		Private Sub NavigationHelper_SaveState(ByVal sender As Object, ByVal e As SaveStateEventArgs)
			' TODO: Save the unique state of the page here.
		End Sub

		#Region "NavigationHelper registration"

		''' <summary>
		''' The methods provided in this section are simply used to allow
		''' NavigationHelper to respond to the page's navigation methods.
		''' <para>
		''' Page specific logic should be placed in event handlers for the  
		''' <see cref="NavigationHelper.LoadState"/>
		''' and <see cref="NavigationHelper.SaveState"/>.
		''' The navigation parameter is available in the LoadState method 
		''' in addition to page state preserved during an earlier session.
		''' </para>
		''' </summary>
		''' <param name="e">Provides data for navigation methods and event
		''' handlers that cannot cancel the navigation request.</param>
		Protected Overrides Sub OnNavigatedTo(ByVal e As NavigationEventArgs)
			Me.navigationHelper_Renamed.OnNavigatedTo(e)
		End Sub

		Protected Overrides Sub OnNavigatedFrom(ByVal e As NavigationEventArgs)
			Me.navigationHelper_Renamed.OnNavigatedFrom(e)
		End Sub

		#End Region

	End Class
End Namespace