﻿Imports MapControlSamples.Common
Imports System
Imports System.Threading.Tasks
Imports Windows.ApplicationModel.Resources
Imports Windows.Devices.Geolocation
Imports Windows.Foundation
Imports Windows.Services.Maps
Imports Windows.UI.Xaml.Controls
Imports Windows.UI.Xaml.Controls.Maps
Imports Windows.UI.Xaml.Media.Imaging
Imports Windows.UI.Xaml.Navigation

Namespace MapControlSamples
	''' <summary>
	''' A page that displays details for a single item within a group.
	''' </summary>
	Public NotInheritable Partial Class ReverseGeocodingPage
		Inherits Page

		Private ReadOnly navigationHelper_Renamed As NavigationHelper
		Private ReadOnly resourceLoader As ResourceLoader = ResourceLoader.GetForCurrentView("Resources")

		Public Sub New()
			Me.InitializeComponent()

			Me.navigationHelper_Renamed = New NavigationHelper(Me)
			AddHandler Me.navigationHelper_Renamed.LoadState, AddressOf NavigationHelper_LoadState
			AddHandler Me.navigationHelper_Renamed.SaveState, AddressOf NavigationHelper_SaveState
		End Sub

		''' <summary>
		''' Gets the <see cref="NavigationHelper"/> associated with this <see cref="Page"/>.
		''' </summary>
		Public ReadOnly Property NavigationHelper() As NavigationHelper
			Get
				Return Me.navigationHelper_Renamed
			End Get
		End Property

		''' <summary>
		''' Populates the page with content passed during navigation. Any saved state is also
		''' provided when recreating a page from a prior session.
		''' </summary>
		''' <param name="sender">
		''' The source of the event; typically <see cref="NavigationHelper"/>.
		''' </param>
		''' <param name="e">Event data that provides both the navigation parameter passed to
		''' <see cref="Frame.Navigate(Type, Object)"/> when this page was initially requested and
		''' a dictionary of state preserved by this page during an earlier
		''' session.  The state will be null the first time a page is visited.</param>
		Private Sub NavigationHelper_LoadState(ByVal sender As Object, ByVal e As LoadStateEventArgs)
		End Sub

		''' <summary>
		''' Preserves state associated with this page in case the application is suspended or the
		''' page is discarded from the navigation cache.  Values must conform to the serialization
		''' requirements of <see cref="SuspensionManager.SessionState"/>.
		''' </summary>
		''' <param name="sender">The source of the event; typically <see cref="NavigationHelper"/>.</param>
		''' <param name="e">Event data that provides an empty dictionary to be populated with
		''' serializable state.</param>
		Private Sub NavigationHelper_SaveState(ByVal sender As Object, ByVal e As SaveStateEventArgs)
			' TODO: Save the unique state of the page here.
		End Sub

		#Region "NavigationHelper registration"

		''' <summary>
		''' The methods provided in this section are simply used to allow
		''' NavigationHelper to respond to the page's navigation methods.
		''' <para>
		''' Page specific logic should be placed in event handlers for the  
		''' <see cref="NavigationHelper.LoadState"/>
		''' and <see cref="NavigationHelper.SaveState"/>.
		''' The navigation parameter is available in the LoadState method 
		''' in addition to page state preserved during an earlier session.
		''' </para>
		''' </summary>
		''' <param name="e">Provides data for navigation methods and event
		''' handlers that cannot cancel the navigation request.</param>
		Protected async Overrides Sub OnNavigatedTo(ByVal e As NavigationEventArgs)
			' Call the navigation helper base function.
			Me.navigationHelper_Renamed.OnNavigatedTo(e)

			' Size the Map Control
			myMapControl.Width = Windows.UI.Xaml.Window.Current.Bounds.Width
			myMapControl.Height = Windows.UI.Xaml.Window.Current.Bounds.Height - 85

			' Get the user's current location.
			Dim geolocator As New Geolocator()
			Dim geoposition As Geoposition = Nothing
			Try
				geoposition = await geolocator.GetGeopositionAsync()
			Catch e1 As Exception
				' Make sure you have defined ID_CAP_LOCATION in the application manifest 
				' and that on your phone, you have turned on location by checking 
				' Settings > Location.

				' Handle errors like unauthorized access to location services
			End Try

			' Set the map center point.
			myMapControl.Center = geoposition.Coordinate.Point

			' add a custom image to represent the current location
			addImageToMap(geoposition.Coordinate.Point)

			' display the address of the current locaiton
			await displayAddress(geoposition.Coordinate.Point)

			' Zoom level
			myMapControl.ZoomLevel = 15

		End Sub

		Protected Overrides Sub OnNavigatedFrom(ByVal e As NavigationEventArgs)
			Me.navigationHelper_Renamed.OnNavigatedFrom(e)
		End Sub

		#End Region

		Private async Sub mcShowLocation_MapTapped(ByVal sender As MapControl, ByVal args As MapInputEventArgs)
			' add the image
			addImageToMap(args.Location)

			' display the address
			await displayAddress(args.Location)
		End Sub

		Private Sub addImageToMap(ByVal geopoint As Geopoint)
			' create an image
			Dim image As New Image()
			image.Width = 40
			image.Height = 40
			Dim bitmapImage As New BitmapImage()
			bitmapImage.UriSource = New Uri("ms-appx:///Assets/PinkPushPin.png")
			image.Source = bitmapImage
			MapControl.SetLocation(image, geopoint)
			MapControl.SetNormalizedAnchorPoint(image, New Point(0.25, 0.9))

			' clear existing children then add the image
			myMapControl.Children.Clear()
			myMapControl.Children.Add(image)
		End Sub

		Private async Function displayAddress(ByVal geopoint As Geopoint) As Task
			' find the address of the tapped location
			Dim result As MapLocationFinderResult = await MapLocationFinder.FindLocationsAtAsync(geopoint)

			' If successful then display the address.
			If result.Status = MapLocationFinderStatus.Success Then
				If result.Locations.Count > 0 Then
					Dim display As String
					If String.IsNullOrEmpty(result.Locations(0).Address.Street) Then
						display = result.Locations(0).Address.Town & ", " & result.Locations(0).Address.Region
					Else
						display = result.Locations(0).Address.StreetNumber & " " & result.Locations(0).Address.Street
					End If

					tbAddress.Text = display
				Else
					Dim msg As String = Me.resourceLoader.GetString("NoAddress")
					tbAddress.Text = msg
				End If
			End If

		End Function

		Private Sub sbTraffic_Click(ByVal sender As Object, ByVal e As Windows.UI.Xaml.RoutedEventArgs)
			If myMapControl.TrafficFlowVisible Then
				myMapControl.TrafficFlowVisible = False
				Dim label As String = Me.resourceLoader.GetString("ShowTrafficFlow")
				sbTraffic.Label = label
			Else
				myMapControl.TrafficFlowVisible = True
				Dim label As String = Me.resourceLoader.GetString("TurnOffTrafficFlow")
				sbTraffic.Label = label
			End If

		End Sub

		Private Sub sbPedestrianFeatures_Click(ByVal sender As Object, ByVal e As Windows.UI.Xaml.RoutedEventArgs)
			If myMapControl.PedestrianFeaturesVisible Then
				myMapControl.PedestrianFeaturesVisible = False
				Dim label As String = Me.resourceLoader.GetString("ShowPedestrianFeatures")
				sbPedestrianFeatures.Label = label
			Else
				myMapControl.PedestrianFeaturesVisible = True
				Dim label As String = Me.resourceLoader.GetString("TurnOffPedestrianFeatures")
				sbPedestrianFeatures.Label = label
			End If
		End Sub

		Private Sub sbLandmarks_Click(ByVal sender As Object, ByVal e As Windows.UI.Xaml.RoutedEventArgs)
			If myMapControl.LandmarksVisible Then
				myMapControl.LandmarksVisible = False
				Dim label As String = Me.resourceLoader.GetString("ShowLandmarks")
				sbLandmarks.Label = label
			Else
				myMapControl.LandmarksVisible = True
				Dim label As String = Me.resourceLoader.GetString("TurnOffLandmarks")
				sbLandmarks.Label = label
			End If
		End Sub

	End Class
End Namespace