﻿Imports MapControlSamples.Common
Imports System
Imports Windows.ApplicationModel.Resources
Imports Windows.Devices.Geolocation
Imports Windows.UI.Xaml.Controls
Imports Windows.UI.Xaml.Controls.Maps
Imports Windows.UI.Xaml.Navigation
Imports MapControlSamples.Models

Namespace MapControlSamples

	''' <summary>
	''' A page that displays details for a single item within a group.
	''' </summary>
	Public NotInheritable Partial Class ScaleControlsPage
		Inherits Page

		Private ReadOnly navigationHelper_Renamed As NavigationHelper
		Private ReadOnly resourceLoader As ResourceLoader = ResourceLoader.GetForCurrentView("Resources")

		Public Sub New()
			Me.InitializeComponent()

			Me.navigationHelper_Renamed = New NavigationHelper(Me)
			AddHandler Me.navigationHelper_Renamed.LoadState, AddressOf NavigationHelper_LoadState
			AddHandler Me.navigationHelper_Renamed.SaveState, AddressOf NavigationHelper_SaveState

		End Sub

		''' <summary>
		''' Gets the <see cref="NavigationHelper"/> associated with this <see cref="Page"/>.
		''' </summary>
		Public ReadOnly Property NavigationHelper() As NavigationHelper
			Get
				Return Me.navigationHelper_Renamed
			End Get
		End Property

		''' <summary>
		''' Populates the page with content passed during navigation. Any saved state is also
		''' provided when recreating a page from a prior session.
		''' </summary>
		''' <param name="sender">
		''' The source of the event; typically <see cref="NavigationHelper"/>.
		''' </param>
		''' <param name="e">Event data that provides both the navigation parameter passed to
		''' <see cref="Frame.Navigate(Type, Object)"/> when this page was initially requested and
		''' a dictionary of state preserved by this page during an earlier
		''' session.  The state will be null the first time a page is visited.</param>
		Private Sub NavigationHelper_LoadState(ByVal sender As Object, ByVal e As LoadStateEventArgs)
			' TODO: Create an appropriate data model for your problem domain to replace the sample data.
		End Sub

		''' <summary>
		''' Preserves state associated with this page in case the application is suspended or the
		''' page is discarded from the navigation cache.  Values must conform to the serialization
		''' requirements of <see cref="SuspensionManager.SessionState"/>.
		''' </summary>
		''' <param name="sender">The source of the event; typically <see cref="NavigationHelper"/>.</param>
		''' <param name="e">Event data that provides an empty dictionary to be populated with
		''' serializable state.</param>
		Private Sub NavigationHelper_SaveState(ByVal sender As Object, ByVal e As SaveStateEventArgs)
			' TODO: Save the unique state of the page here.
		End Sub

		#Region "NavigationHelper registration"

		''' <summary>
		''' The methods provided in this section are simply used to allow
		''' NavigationHelper to respond to the page's navigation methods.
		''' <para>
		''' Page specific logic should be placed in event handlers for the  
		''' <see cref="NavigationHelper.LoadState"/>
		''' and <see cref="NavigationHelper.SaveState"/>.
		''' The navigation parameter is available in the LoadState method 
		''' in addition to page state preserved during an earlier session.
		''' </para>
		''' </summary>
		''' <param name="e">Provides data for navigation methods and event
		''' handlers that cannot cancel the navigation request.</param>
		Protected async Overrides Sub OnNavigatedTo(ByVal e As NavigationEventArgs)
			' Call the navigation helper base function.
			Me.navigationHelper_Renamed.OnNavigatedTo(e)

			' Size the Map Control
			myMapControl.Width = Windows.UI.Xaml.Window.Current.Bounds.Width
			myMapControl.Height = Windows.UI.Xaml.Window.Current.Bounds.Height - 85

			' Get the user's current location so that it can be used as the center
			' point of the map control.
			Dim geolocator As New Geolocator()
			Dim geoposition As Geoposition = Nothing
			Try
				geoposition = await geolocator.GetGeopositionAsync()
            Catch e1 As Exception
                ' Make sure you have defined ID_CAP_LOCATION in the application manifest 
                ' and that on your phone, you have turned on location by checking 
                ' Settings > Location.

                ' Handle errors like unauthorized access to location services
			End Try

			' Set the map center point.
			Dim locationEntity As New LocationEntity()
			locationEntity.Location = geoposition.Coordinate.Point
			locationEntity.Message = "You are here"

			' Specify the location that will be at the center of the map.
			myMapControl.Center = locationEntity.Location

			' Set the map controls data context so data binding will work.
			myMapControl.DataContext = locationEntity

			' Zoom level.  
			myMapControl.ZoomLevel = 15

			' The map control has done most of its work.  Make the controls visible
			' and collapse the progress bar.
			imgMyLocation.Visibility = Windows.UI.Xaml.Visibility.Visible
			borderMessage.Visibility = Windows.UI.Xaml.Visibility.Visible
			pbProgressBar.Visibility = Windows.UI.Xaml.Visibility.Collapsed
		End Sub

		Protected Overrides Sub OnNavigatedFrom(ByVal e As NavigationEventArgs)
			Me.navigationHelper_Renamed.OnNavigatedFrom(e)
		End Sub

		#End Region

		Private Sub myMapControl_ZoomLevelChanged(ByVal sender As MapControl, ByVal args As Object)
			' Get the map control's current zoom level.
			Dim zoomLevel As Double = sender.ZoomLevel

			' Use the latitude from the center point of the map control.
			Dim latitude As Double = sender.Center.Position.Latitude

			' Hard coded test values so that the results of the equation below can be compared to the chart at
			' http://msdn.microsoft.com/en-us/library/aa940990.aspx.
			'latitude = 0;
			'zoomLevel = 1;

			' The following formula for map resolution  needs latitude in radians.
			latitude = latitude * (Math.PI / 180)

			' This constant is based on the diameter of the Earth and the equations Microsoft uses to determine the map 
			' shown for the map control's zoom level.
			Const BING_MAP_CONSTANT As Double = 156543.04

			' Calculate the number of meters represented by a single pixel. 
			Dim MetersPerPixel As Double = BING_MAP_CONSTANT * Math.Cos(latitude) / Math.Pow(2, zoomLevel)
			Dim KilometersPerPixel As Double = MetersPerPixel / 1000
			Dim FeetPerPixel As Double = MetersPerPixel * 3.28
			Dim MilesPerPixel As Double = FeetPerPixel / 5280

			If System.Globalization.RegionInfo.CurrentRegion.IsMetric Then
				' Determine the distance represented by the rectangle control.
				Dim scaleDistance As Double = recScale.Width * KilometersPerPixel

				' Use meters if scale distance is less than 1 kilometer
				If scaleDistance < 1 Then
					scaleDistance = recScale.Width * MetersPerPixel
					scaleDistance = Math.Round(scaleDistance, 1)
					tbScale.Text = scaleDistance.ToString() & " m"
				Else
					scaleDistance = Math.Round(scaleDistance, 1)
					tbScale.Text = scaleDistance.ToString() & " km"
				End If
			Else
				' Determine the distance represented by the rectangle control.
				Dim scaleDistance As Double = recScale.Width * MilesPerPixel

				' Use meters if scale distance is less than 1 kilometer
				If scaleDistance < 1 Then
					scaleDistance = recScale.Width * FeetPerPixel
					scaleDistance = Math.Round(scaleDistance, 1)
					tbScale.Text = scaleDistance.ToString() & " feet"
				Else
					scaleDistance = Math.Round(scaleDistance, 1)
					tbScale.Text = scaleDistance.ToString() & " miles"
				End If

			End If

		End Sub



	End Class
End Namespace