﻿Imports MapControlSamples.Common
Imports System
Imports Windows.ApplicationModel.Resources
Imports Windows.Devices.Geolocation
Imports Windows.Services.Maps
Imports Windows.UI
Imports Windows.UI.Popups
Imports Windows.UI.Xaml.Controls
Imports Windows.UI.Xaml.Controls.Maps
Imports Windows.UI.Xaml.Documents
Imports Windows.UI.Xaml.Navigation

Namespace MapControlSamples
	''' <summary>
	''' A page that displays details for a single item within a group.
	''' </summary>
	Public NotInheritable Partial Class WalkingRoutesPage
		Inherits Page

		Private ReadOnly navigationHelper_Renamed As NavigationHelper
		Private ReadOnly resourceLoader As ResourceLoader = ResourceLoader.GetForCurrentView("Resources")

		Public Sub New()
			Me.InitializeComponent()

			Me.navigationHelper_Renamed = New NavigationHelper(Me)
			AddHandler Me.navigationHelper_Renamed.LoadState, AddressOf NavigationHelper_LoadState
			AddHandler Me.navigationHelper_Renamed.SaveState, AddressOf NavigationHelper_SaveState
		End Sub

		''' <summary>
		''' Gets the <see cref="NavigationHelper"/> associated with this <see cref="Page"/>.
		''' </summary>
		Public ReadOnly Property NavigationHelper() As NavigationHelper
			Get
				Return Me.navigationHelper_Renamed
			End Get
		End Property

		''' <summary>
		''' Populates the page with content passed during navigation. Any saved state is also
		''' provided when recreating a page from a prior session.
		''' </summary>
		''' <param name="sender">
		''' The source of the event; typically <see cref="NavigationHelper"/>.
		''' </param>
		''' <param name="e">Event data that provides both the navigation parameter passed to
		''' <see cref="Frame.Navigate(Type, Object)"/> when this page was initially requested and
		''' a dictionary of state preserved by this page during an earlier
		''' session.  The state will be null the first time a page is visited.</param>
		Private Sub NavigationHelper_LoadState(ByVal sender As Object, ByVal e As LoadStateEventArgs)
		End Sub

		''' <summary>
		''' Preserves state associated with this page in case the application is suspended or the
		''' page is discarded from the navigation cache.  Values must conform to the serialization
		''' requirements of <see cref="SuspensionManager.SessionState"/>.
		''' </summary>
		''' <param name="sender">The source of the event; typically <see cref="NavigationHelper"/>.</param>
		''' <param name="e">Event data that provides an empty dictionary to be populated with
		''' serializable state.</param>
		Private Sub NavigationHelper_SaveState(ByVal sender As Object, ByVal e As SaveStateEventArgs)
			' TODO: Save the unique state of the page here.
		End Sub

		#Region "NavigationHelper registration"

		''' <summary>
		''' The methods provided in this section are simply used to allow
		''' NavigationHelper to respond to the page's navigation methods.
		''' <para>
		''' Page specific logic should be placed in event handlers for the  
		''' <see cref="NavigationHelper.LoadState"/>
		''' and <see cref="NavigationHelper.SaveState"/>.
		''' The navigation parameter is available in the LoadState method 
		''' in addition to page state preserved during an earlier session.
		''' </para>
		''' </summary>
		''' <param name="e">Provides data for navigation methods and event
		''' handlers that cannot cancel the navigation request.</param>
		Protected async Overrides Sub OnNavigatedTo(ByVal e As NavigationEventArgs)
			Me.navigationHelper_Renamed.OnNavigatedTo(e)

			' Size the Map Control
			myMapControl.Width = Windows.UI.Xaml.Window.Current.Bounds.Width
			myMapControl.Height = Windows.UI.Xaml.Window.Current.Bounds.Height - 85

			' start at Grand Central Station
			Dim startLocation As New BasicGeoposition()
			startLocation.Latitude = 40.7517
			startLocation.Longitude = -073.9766
			Dim startPoint As New Geopoint(startLocation)

			' end at Central Park
			Dim endLocation As New BasicGeoposition()
			endLocation.Latitude = 40.7669
			endLocation.Longitude = -073.9790
			Dim endPoint As New Geopoint(endLocation)

			' Get the route between the points.
			Dim routeResult As MapRouteFinderResult = await MapRouteFinder.GetWalkingRouteAsync(startPoint, endPoint)

			If routeResult.Status = MapRouteFinderStatus.Success Then
				' Display summary info about the route.
				tbTurnByTurn.Inlines.Add(New Run() With {.Text = resourceLoader.GetString("Summary")})

				tbTurnByTurn.Inlines.Add(New LineBreak())
				tbTurnByTurn.Inlines.Add(New LineBreak())

				tbTurnByTurn.Inlines.Add(New Run() With {.Text = resourceLoader.GetString("TotalTime") & " = " & routeResult.Route.EstimatedDuration.TotalMinutes.ToString("F1")})
				tbTurnByTurn.Inlines.Add(New LineBreak())
				tbTurnByTurn.Inlines.Add(New Run() With {.Text = resourceLoader.GetString("TotalLength") & " = " & (routeResult.Route.LengthInMeters / 1000).ToString("F1")})
				tbTurnByTurn.Inlines.Add(New LineBreak())
				tbTurnByTurn.Inlines.Add(New LineBreak())

				' Display the directions.
				tbTurnByTurn.Inlines.Add(New Run() With {.Text = resourceLoader.GetString("Directions")})

				tbTurnByTurn.Inlines.Add(New LineBreak())
				tbTurnByTurn.Inlines.Add(New LineBreak())

				' loop through the legs and maneuvers
				For Each leg As MapRouteLeg In routeResult.Route.Legs
					For Each maneuver As MapRouteManeuver In leg.Maneuvers
						tbTurnByTurn.Inlines.Add(New Run() With {.Text = maneuver.InstructionText})

						tbTurnByTurn.Inlines.Add(New LineBreak())
						tbTurnByTurn.Inlines.Add(New LineBreak())
					Next maneuver

				Next leg

				' Use the route to initialize a MapRouteView.
				Dim viewOfRoute As New MapRouteView(routeResult.Route)
				viewOfRoute.RouteColor = Colors.Blue
				viewOfRoute.OutlineColor = Colors.Blue

				' Add the new MapRouteView to the Routes collection
				' of the MapControl.
				myMapControl.Routes.Add(viewOfRoute)

				' Fit the MapControl to the route.
                Await myMapControl.TrySetViewBoundsAsync(routeResult.Route.BoundingBox, Nothing, Windows.UI.Xaml.Controls.Maps.MapAnimationKind.Bow)

			Else
				' Tell the user to try again.
				Dim message As String = Me.resourceLoader.GetString("NoRoute")
				Dim title As String = Me.resourceLoader.GetString("NoRouteTitle")
				Dim messageDialog As New MessageDialog(message, title)
				await messageDialog.ShowAsync()
			End If

			' Collapse the progress bar.
			pbProgressBar.Visibility = Windows.UI.Xaml.Visibility.Collapsed
		End Sub

		Protected Overrides Sub OnNavigatedFrom(ByVal e As NavigationEventArgs)
			Me.navigationHelper_Renamed.OnNavigatedFrom(e)
		End Sub

		#End Region

		Private Sub abbMap_Click(ByVal sender As Object, ByVal e As Windows.UI.Xaml.RoutedEventArgs)
			myMapControl.Visibility = Windows.UI.Xaml.Visibility.Visible
			tbTurnByTurn.Visibility = Windows.UI.Xaml.Visibility.Collapsed
			abbMap.IsEnabled = False
			abbDirections.IsEnabled = True
		End Sub

		Private Sub abbDirections_Click(ByVal sender As Object, ByVal e As Windows.UI.Xaml.RoutedEventArgs)
			myMapControl.Visibility = Windows.UI.Xaml.Visibility.Collapsed
			tbTurnByTurn.Visibility = Windows.UI.Xaml.Visibility.Visible
			abbMap.IsEnabled = True
			abbDirections.IsEnabled = False
		End Sub

	End Class
End Namespace